% my $p = shift;
#!/usr/bin/env perl

use strict;
use warnings;

use FindBin;
use lib "$FindBin::Bin/../lib";
use lib "$FindBin::Bin/../thirdparty/lib/perl5";
use Mojolicious::Commands;

Mojolicious::Commands->start_app('<%= $p->{class} %>');
<%= '__END__' %>

